Commit 8ec0a5527333afeca3f4ff3bf36fb8e1ac1c5939

Jacques Germishuys 2014-04-18T00:49:07

Make git_cred_ssh_custom_new() naming more consistent

diff --git a/src/transports/cred.c b/src/transports/cred.c
index 528d6af..05090ba 100644
--- a/src/transports/cred.c
+++ b/src/transports/cred.c
@@ -204,7 +204,7 @@ int git_cred_ssh_custom_new(
 	const char *publickey,
 	size_t publickey_len,
 	git_cred_sign_callback sign_callback,
-	void *sign_data)
+	void *payload)
 {
 	git_cred_ssh_custom *c;
 
@@ -228,7 +228,7 @@ int git_cred_ssh_custom_new(
 
 	c->publickey_len = publickey_len;
 	c->sign_callback = sign_callback;
-	c->sign_data = sign_data;
+	c->payload = payload;
 
 	*cred = &c->parent;
 	return 0;
diff --git a/src/transports/ssh.c b/src/transports/ssh.c
index 48e51f2..dea9902 100644
--- a/src/transports/ssh.c
+++ b/src/transports/ssh.c
@@ -310,7 +310,7 @@ static int _git_ssh_authenticate_session(
 
 			rc = libssh2_userauth_publickey(
 				session, c->username, (const unsigned char *)c->publickey,
-				c->publickey_len, c->sign_callback, &c->sign_data);
+				c->publickey_len, c->sign_callback, &c->payload);
 			break;
 		}
 		case GIT_CREDTYPE_SSH_INTERACTIVE: {
diff --git a/include/git2/transport.h b/include/git2/transport.h
index eba08cd..80299c4 100644
--- a/include/git2/transport.h
+++ b/include/git2/transport.h
@@ -99,7 +99,7 @@ typedef struct git_cred_ssh_custom {
 	char *publickey;
 	size_t publickey_len;
 	void *sign_callback;
-	void *sign_data;
+	void *payload;
 } git_cred_ssh_custom;
 
 /** A key for NTLM/Kerberos "default" credentials */
@@ -186,8 +186,8 @@ GIT_EXTERN(int) git_cred_ssh_key_from_agent(
  * @param username username to use to authenticate
  * @param publickey The bytes of the public key.
  * @param publickey_len The length of the public key in bytes.
  * @param sign_fn The callback method to sign the data during the challenge.
  * @param sign_data The data to pass to the sign function.
  * @return 0 for success or an error code for failure
  */
 GIT_EXTERN(int) git_cred_ssh_custom_new(
@@ -195,8 +195,8 @@ GIT_EXTERN(int) git_cred_ssh_custom_new(
 	const char *username,
 	const char *publickey,
 	size_t publickey_len,
-	git_cred_sign_callback sign_fn,
-	void *sign_data);
+	git_cred_sign_callback sign_callback,
+	void *payload);
 
 /**
  * Create a "default" credential usable for Negotiate mechanisms like NTLM
@@ -186,8 +186,8 @@ GIT_EXTERN(int) git_cred_ssh_key_from_agent(
  * @param publickey The bytes of the public key.
  * @param publickey_len The length of the public key in bytes.
- * @param sign_fn The callback method to sign the data during the challenge.
- * @param sign_data The data to pass to the sign function.
+ * @param sign_callback The callback method to sign the data during the challenge.
+ * @param payload Additional data to pass to the callback.
  * @return 0 for success or an error code for failure
  */